//@flow
/**
 * @author Sven Koelpin
 */
import React, { PureComponent } from 'react';
import style from './chatWindow.css';
import type { Chat } from '../domain/Entities';

type Props = {|
    chat: Chat,
    markAsRead: (chat: Chat) => void;
|}

export const formatTimeStamp = (timestamp: number): string => {
    const date = new Date(timestamp);
    return date.getHours() + ':' + date.getMinutes() + ':' + date.getSeconds()
};

export class ChatWindow extends PureComponent<void, Props, void> {
    props: Props;

    constructor(props: Props) {
        super(props);
        (this: any).markAsRead = this.markAsRead.bind(this);
    }

    markAsRead() {
        const {chat, markAsRead} = this.props;
        markAsRead(chat);
    }

    render() {
        const {chat} = this.props;
        return (
            <section className={`${style.chat} ${chat.unread ? style.unread : ''}`} onClick={this.markAsRead}>
                <div className={style.title}>
                    {chat.user.name} {chat.user.online ? <span className={style.online}/> : <span className={style.offline}/>}
                </div>
                <ul className={style.messages}>
                    {chat.messages.map(message => {
                        return (
                            <li key={message.id}>
                                <div>{formatTimeStamp(message.time)}:</div>
                                {message.message}
                            </li>
                        );
                    })}
                </ul>
            </section>
        );
    }
}